==> haskell-pretty-simple-4.1.2.0-72-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-simple
version:              4.1.2.0
visibility:           public
id:                   pretty-simple-4.1.2.0-ENlZRorZ6zSBGuiYeRYYHZ
key:                  pretty-simple-4.1.2.0-ENlZRorZ6zSBGuiYeRYYHZ
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  8e3fd1dc32266bb8e032c35841d0fd69
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.2.0-ENlZRorZ6zSBGuiYeRYYHZ
depends:
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2
    prettyprinter-1.7.1-4X811DzHwplE7Du7oIbLHM
    prettyprinter-ansi-terminal-1.1.3-IuN8x6IJGfYBDtUvUAjq23
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-simple-4.1.2.0-81-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-simple
version:              4.1.2.0
visibility:           public
id:                   pretty-simple-4.1.2.0-4DdVydWy2oILgJsCq2PDX0
key:                  pretty-simple-4.1.2.0-4DdVydWy2oILgJsCq2PDX0
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  e348e5b52bf07a36d484c8ce115b99fc
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pretty-simple-4.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.2.0-4DdVydWy2oILgJsCq2PDX0
depends:
    base-4.16.4.0 containers-0.6.5.1 mtl-2.2.2
    prettyprinter-1.7.1-6Wsg7uF6NF3C9EkVjlD5S1
    prettyprinter-ansi-terminal-1.1.3-8oO97RT2laQgzPfmsyMvY
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
